ledger.JournalsOverview (Journals) — amici1

# `ledger.JournalsOverview` (Journals)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.CharField: ref>`

- `<django.db.models.fields.IntegerField: seqno>`

- `<lino.utils.mldbc.fields.BabelCharField: name>`

- `<lino.core.choicelists.ChoiceListField: build_method>`

- `<django.db.models.fields.CharField: template>`

- `<lino.core.choicelists.ChoiceListField: trade_type>`

- `<lino.core.choicelists.ChoiceListField: voucher_type>`

- `<lino.core.choicelists.ChoiceListField: journal_group>`

- `<django.db.models.fields.BooleanField: auto_check_clearings>`

- `<django.db.models.fields.BooleanField: auto_fill_suggestions>`

- `<django.db.models.fields.BooleanField: force_sequence>`

- `<django.db.models.fields.BooleanField: preliminary>`

- `<django.db.models.fields.related.ForeignKey: account>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.utils.mldbc.fields.BabelCharField: printed_name>`

- `<lino.core.choicelists.ChoiceListField: dc>`

- `<django.db.models.fields.BooleanField: yearly_numbering>`

- `<django.db.models.fields.BooleanField: must_declare>`

- `<django.db.models.fields.related.ForeignKey: uploads_volume>`

- `<django.db.models.fields.related.ForeignKey: sepa_account>`

Detail fields

- `<Panel main_1 in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

- `<Panel main_2 in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

- `<Panel main_3 in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

- `<Panel main_4 in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

- `<Panel main_5 in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

- `<GridElement MatchRulesByJournal in lino_xl.lib.ledger.ui.JournalDetail on lino_xl.lib.ledger.ui.Journals>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate this row.

- Detail (detail) : Open a detail window on this record.

- Merge (merge_row) : See `<lino.core.merge.MergeAction merge_row ('Merge')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (move_by_n) : Move this row N rows upwards or downwards.

- ▼ (move_down) : Exchange the seqno of this item and the next item.

- ▲ (move_up) : Exchange the seqno of this item and the previous item.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

## Filter parameters